<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="nl" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Categorie:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Torrent starten</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Hash-check overslaan</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Submap aanmaken</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Torrent-beheermodus:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Zonder categorie</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Categorie toevoegen...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Categorie verwijderen</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Niet-gebruikte categorieën verwijderen</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Torrents hervatten</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Torrents pauzeren</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Torrents verwijderen</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nieuwe categorie</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Categorie bewerken...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>qBittorrent afsluiten</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Slechts één link per regel</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Algemene begrenzing voor uploadsnelheid moet groter dan 0 of uitgeschakeld zijn.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Algemene begrenzing voor downloadsnelheid moet groter dan 0 of uitgeschakeld zijn.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatieve begrenzing voor uploadsnelheid moet groter dan 0 of uitgeschakeld zijn.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatieve begrenzing voor downloadsnelheid moet groter dan 0 of uitgeschakeld zijn.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Maximaal aantal actieve downloads moet groter zijn dan -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Maximaal aantal actieve uploads moet groter zijn dan -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Maximaal aantal actieve torrents moet groter zijn dan -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Limiet voor maximaal aantal verbindingen moet groter zijn dan 0 of uitgeschakeld.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Limiet voor maximaal aantal verbindingen per torrent moet groter zijn dan 0 of uitgeschakeld.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Limiet voor maximaal aantal uploadslots per torrent moet groter zijn dan 0 of uitgeschakeld.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Onmogelijk om programmavoorkeuren op te slaan, qBittorrent is waarschijnlijk onbereikbaar.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent op Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Begrenzing voor deelverhouding moet tussen 0 en 9998 liggen.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Begrenzing voor seed-tijd moet liggen tussen 0 en 525 600 minuten.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>De poort gebruikt voor inkomende verbindingen moet liggen tussen 1 en 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>De poort gebruikt voor de Web-UI moet liggen tussen 1 en 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Niet mogelijk om in te loggen, qBittorrent is waarschijnlijk onbereikbaar.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Ongeldige gebruikersnaam of wachtwoord.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Oorspronkelijke auteurs</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Toepassen</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Torrents uploaden</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Bestanden opslaan in:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Map hier typen</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Meer informatie</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Informatie over certificaten</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Locatie instellen</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Uploadsnelheid begrenzen</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Downloadsnelheid begrenzen</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Naam van torrent wijzigen</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Andere...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Maandag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Dinsdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Woensdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Donderdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Vrijdag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Zaterdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Zondag</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Torrents downloaden via hun URL's of magneetlinks</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Lokale torrent uploaden</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Weet u zeker dat u de geselecteerde torrents wilt verwijderen uit de overdrachtlijst?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>qBittorrent-client is niet bereikbaar</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Limiet voor algemeen aantal uploadslots moet groter zijn dan 0 of uitgeschakeld.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Ongeldige categorienaam:\nGebruik geen speciale tekens in de categorienaam.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Kon categorie niet aanmaken</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Drempel voor uploadsnelheid moet hoger zijn dan 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Vrije ruimte: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Inactiviteitstimer van torrent moet groter zijn dan 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Opslagbeheer</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>Drempel voor downloadsnelheid moet hoger zijn dan 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent werd afgesloten</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Extra</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Bestand</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Beeld</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Opties...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Hervatten</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Laagste prioriteit</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Hoogste prioriteit</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Prioriteit verlagen</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Prioriteit verhogen</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Bovenste werkbalk</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Statusbalk</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Snelheid in titelbalk</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Doneren!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Alles hervatten</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistieken</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Alles pauzeren</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Torrentbestand toevoegen...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Documentatie</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Torrent-link toevoegen</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nee</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Algemene uploadsnelheidbegrenzing</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Algemene downloadsnelheidbegrenzing</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Weet u zeker dat u qBittorrent wilt afsluiten?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[D: %1, U: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Alternatieve snelheidsbegrenzingen</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Zoekmachine</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Torrentlijst filteren...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Overdrachten</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Verbinding</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Snelheid</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Web-UI</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Taal</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Taal gebruikersinterface:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Melding via e-mail wanneer download voltooid is</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Extern programma uitvoeren bij voltooien van de torrent</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP-filtering</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Gebruik van alternatieve snelheidsbegrenzingen inplannen</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrents in wachtrij plaatsen</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Torrents seeden totdat ze een seed-tijd bereiken van</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Deze trackers automatisch toevoegen aan nieuwe downloads:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Web-gebruikersinterface (bediening op afstand)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP-adres:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Server-domeinen:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>HTTPS in plaats van HTTP gebruiken</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Authenticatie overslaan voor clients op localhost</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Authenticatie overslaan voor clients in toegestane IP-subnets</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Mijn dynamische domeinnaam bijwerken</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Onvoltooide torrents bewaren in:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Torrentbestanden kopiëren naar:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Torrentbestanden voor voltooide downloads kopiëren naar:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Schijfruimte vooraf toewijzen voor alle bestanden</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>.!qB-extensie toevoegen aan onvolledige bestanden</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Torrents automatisch toevoegen vanuit:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP-server:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Deze server vereist een veilige verbinding (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Authenticatie</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Gebruikersnaam:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Ingeschakeld protocol:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP en µTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Luisterpoort</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Poort voor inkomende verbindingen:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>UPnP/NAT-PMP port forwarding van mijn router gebruiken</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Bij elke opstart een andere poort gebruiken</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Begrenzing verbindingen</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Maximaal aantal verbindingen per torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Algemeen maximaal aantal verbindingen:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Maximaal aantal uploadslots per torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Algemeen maximaal aantal uploadslots:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Proxy-server</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Geen)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Poort:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Proxy gebruiken voor peer-verbindingen</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Verbindingen die niet ondersteund worden door proxy's uitschakelen</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Proxy alleen voor torrents gebruiken</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Filterpad (.dat, p2p, p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Manueel verbannen IP-adressen...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Toepassen op trackers</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Algemene snelheidsbegrenzingen</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Upload:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Download:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Alternatieve snelheidsbegrenzingen</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Van:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Tot:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Wanneer:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Elke dag</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Weekdagen</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Weekends</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Instellingen snelheidsbegrenzing</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Snelheidsbegrenzing toepassen op transport-overhead</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Snelheidsbegrenzing toepassen op µTP-protocol</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privacy</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>DHT (decentralized network) inschakelen om meer peers te vinden</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Peer Exchange (PeX) inschakelen om meer peers te vinden</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Lokale peer-ontdekking inschakelen om meer peers te vinden</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Encryptiemodus:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Encryptie verkiezen</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Encryptie vereisen</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Encryptie uitschakelen</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Anonieme modus inschakelen</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Maximaal aantal actieve downloads:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Maximaal aantal actieve uploads:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Maximaal aantal actieve torrents:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Trage torrents niet meerekenen bij deze begrenzingen</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Deelverhouding begrenzen</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Torrents seeden totdat ze een verhouding bereiken van</translation>
    </message>
    <message>
        <source>then</source>
        <translation>en ze dan</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>pauzeren</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>verwijderen</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>UPnP/NAT-PMP gebruiken om de poort van mijn router te forwarden</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certificaat:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Sleutel:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registreren</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Domeinnaam:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Ondersteunde parameters (hoofdlettergevoelig):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: naam torrent</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: categorie</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation>%G: labels (gescheiden door komma)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: pad naar inhoud (zelfde als root-pad voor torrent met meerdere bestanden)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: root-pad (pad naar eerste submap van torrent)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: opslagpad</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: aantal bestanden</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: grootte torrent (bytes)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: huidige tracker</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: info-hash</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Tip: omring de parameter met aanhalingstekens om te vermijden dat tekst afgekapt wordt bij witruimte (bijvoorbeeld: "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>De Web-UI-gebruikersnaam moet minstens 3 tekens lang zijn.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Het Web-UI-wachtwoord moet minstens 6 tekens lang zijn.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuten</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Clickjacking-bescherming inschakelen</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Bescherming tegen Cross-Site Request Forgery (CSRF) inschakelen</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Torrentbestanden nadien verwijderen</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Downloadsnelheid-drempel:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Uploadsnelheid-drempel:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Huidig wachtwoord wijzigen</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Alternatieve web-UI gebruiken</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Standaard opslagpad:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>De alternatieve locatie van Web-UI-bestanden mag niet leeg zijn.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Download niet automatisch starten</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Torrent wisselen naar handmatige modus</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Wanneer torrentcategorie wijzigt:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Beïnvloede torrents verplaatsen</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Snelheidslimiet toepassen op peers op LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 betekent onbegrensd</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Torrent verplaatsen</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Wanneer standaard opslagpad wijzigt:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Validatie van host-header inschakelen</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Beveiliging</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Wanneer categorie-opslagpad wijzigt:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Submap aanmaken voor torrents met meerdere bestanden</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>seconden</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Beïnvloede torrents wisselen naar handmatige modus</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Locatie van bestanden:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manueel</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Inactiviteitstimer van torrent:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Standaard torrent-beheermodus:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Bij toevoegen torrent</translation>
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Poort</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Vlaggen</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Verbinding</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Cliënt</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Voortgang</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Downloadsnelheid</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Uploadsnelheid</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Gedownload</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Geüpload</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Relevantie</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Bestanden</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Land</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normaal</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Hoog</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Trackers</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Peers</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP-bronnen</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Inhoud</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Gedownload:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Overdracht</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Tijd actief:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Geschatte resterende tijd:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Geüpload:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Seeds:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Downloadsnelheid:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Uploadsnelheid:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Peers:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Downloadbegrenzing:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Uploadbegrenzing:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Verloren:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Verbindingen:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Opmerkingen:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Deelverhouding:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Opnieuw aankondigen over:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Laatst volledig gezien:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Totale grootte:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Deeltjes:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Aangemaakt door:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Toegevoegd op:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Voltooid op:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Aangemaakt op:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrent-hash:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Opslagpad:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nooit</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (%3 in bezit)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 deze sessie)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 max)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 totaal)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 gem.)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Downloadbegrenzing:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Uploadbegrenzing:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Gemonitorde map</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Opslaglocatie overschrijven</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Gemonitorde map</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Standaard opslaglocatie</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statistieken</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Gebruikersstatistieken</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Buffer-statistieken</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Leesbuffer-hits:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Gemiddelde tijd in wachtrij:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Verbonden peers:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Deelverhouding van altijd:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Download van altijd:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Sessie-verlies:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Upload van altijd:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Totale buffergrootte:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Prestatiestatistieken</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>I/O-taken in wachtrij:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Schrijfbuffer-overbelasting:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Leesbuffer-overbelasting:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Totale grootte van wachtrij:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 nodes</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Alles (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Downloaden (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Seeden (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Voltooid (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Hervat (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Gepauzeerd (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Actief (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Niet actief (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Met fouten (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Alles (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Downloaden (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Seeden (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Voltooid (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Gepauzeerd (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Hervat (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Actief (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Niet actief (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Met fouten (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Voortgang</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Downloadprioriteit</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Resterend</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Beschikbaarheid</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Grootte</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Klaar</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Status</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Seeds</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Peers</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Downloadsnelheid</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Uploadsnelheid</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Verhouding</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Geschatte resterende tijd</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categorie</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Labels</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Toegevoegd op</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Voltooid op</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Downloadbegrenzing</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Uploadbegrenzing</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Gedownload</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Geüpload</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Sessie-download</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Sessie-upload</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Resterend</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Tijd actief</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Opslagpad</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Voltooid</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Begrenzing deelverhouding</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Laatst volledig gezien</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Laatste activiteit</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Totale grootte</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Peers</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Bericht</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Gedownload</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>Tracker-URL:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Bijwerken...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Werkend</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Uitgeschakeld</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Nog niet gecontacteerd</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/B</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Seeds</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Niet werkend</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Tracker-URL kopiëren</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Nieuwe tracker toevoegen...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Tracker-URL bewerken...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Tracker bewerken</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Leeches</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Tracker verwijderen</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Trackers toevoegen-venster</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Lijst van toe te voegen trackers (een per regel):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 geleden</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Toewijzen</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Gepauzeerd</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Voltooid</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Verplaatsen</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] seeden</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Seeden</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>In wachtrij</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Met fouten</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] downloaden</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Metadata downloaden</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Controleren</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Ontbrekende bestanden</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>In wachtrij voor controleren</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Hervattingsdata controleren</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Wachten</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Categorieën</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Begrenzing downloadsnelheid torrent</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Begrenzing uploadsnelheid torrent</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Hervatten</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Geforceerd hervatten</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Deelverhouding begrenzen...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Uploadsnelheid begrenzen...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Downloadsnelheid begrenzen...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Omhoog verplaatsen</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Omlaag verplaatsen</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Bovenaan plaatsen</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Onderaan plaatsen</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Locatie instellen...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Naam kopiëren</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Hash kopiëren</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Eerste en laatste deeltjes eerst downloaden</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Automatisch torrent-beheer</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categorie</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Nieuw...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Herstellen</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioriteit</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Opnieuw controleren forceren</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Magneetlink kopiëren</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Super-seeding-modus</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Naam wijzigen...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>In sequentiële volgorde downloaden</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Opnieuw controleren forceren</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nieuwe categorie</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Locatie</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Nieuwe naam</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Locatie instellen</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Opnieuw aankondigen forceren</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Categorie bewerken</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Opslagpad</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Upload/downloadverhouding van torrent begrenzen</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Algemene deelbegrenzing gebruiken</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Geen deelbegrenzing instellen</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Deelbegrenzing instellen op</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>verhouding</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuten</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Een geavanceerde BitTorrent-client geprogrammeerd in C++, gebaseerd op Qt-toolkit en libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Homepagina:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Forum:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Bug-tracker:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Bevestiging verwijdering</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Ook bestanden op de harde schijf verwijderen</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Bevestiging verwijdering - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Downloaden uit URL's</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Torrent-links toevoegen</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1 h %2 m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1 d %2 h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Onbekend</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1 m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1 m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Opslagpad is leeg</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Plugin-pad:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL of lokale map</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Plugin installeren</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Seeds:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Alle plugins</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Grootte:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Zoekplugins...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Alle categorieën</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Zoeken in:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>URL van beschrijvingspagina kopiëren</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Naar de beschrijvingspagina gaan</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Resultaten (</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Alleen torrentnamen</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Alleen ingeschakeld</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>van</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Overal</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Deïnstalleren</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Nieuwe plugin installeren</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>U kunt hier nieuwe zoekplugins verkrijgen:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Geïnstalleerde zoekplugins:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Ingeschakeld</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Waarschuwing: verzeker u ervan dat u voldoet aan de wetten op auteursrecht in uw land wanneer u torrents downloadt via een van deze zoekmachines.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Controleren op updates</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Zoekplugins</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Leechers</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Zoekmachine</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Seeders</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Ingeschakeld</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versie</translation>
    </message>
</context>
</TS>